@@ -1,13 +1,7 @@
-package Dist::Zilla::App 6.018; # TRIAL
+package Dist::Zilla::App 6.026; # TRIAL
 # ABSTRACT: Dist::Zilla's App::Cmd
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use App::Cmd::Setup 0.330 -app; # better compilation error detection
 
@@ -18,9 +12,7 @@ use namespace::autoclean;
 
 $Carp::Internal{'Module::Runtime'} = 1;
 
-sub global_opt_spec {
-  my ($self) = @_;
-
+sub global_opt_spec ($self) {
   return (
     [ "verbose|v",           "log additional output" ],
     [ "verbose-plugin|V=s@", "log additional output from some plugins only" ],
@@ -31,9 +23,7 @@ sub global_opt_spec {
   );
 }
 
-sub _build_global_stashes {
-  my ($self) = @_;
-
+sub _build_global_stashes ($self) {
   return $self->{__global_stashes__} if $self->{__global_stashes__};
 
   # tests shouldn't depend on the user's configuration
@@ -106,8 +96,7 @@ END_DIE
 #pod
 #pod =cut
 
-sub chrome {
-  my ($self) = @_;
+sub chrome ($self) {
   require Dist::Zilla::Chrome::Term;
 
   return $self->{__chrome__} if $self->{__chrome__};
@@ -125,9 +114,7 @@ sub chrome {
   return $self->{__chrome__};
 }
 
-sub zilla {
-  my ($self) = @_;
-
+sub zilla ($self) {
   require Dist::Zilla::Dist::Builder;
 
   return $self->{'' . __PACKAGE__}{zilla} ||= do {
@@ -183,13 +170,14 @@ Dist::Zilla::App - Dist::Zilla's App::Cmd
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -205,11 +193,11 @@ been constructed, one will be by calling C<< Dist::Zilla->from_config >>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
