@@ -1,13 +1,7 @@
-package Dist::Zilla::App::Command::listdeps 6.018; # TRIAL
+package Dist::Zilla::App::Command::listdeps 6.026; # TRIAL
 # ABSTRACT: print your distribution's prerequisites
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Dist::Zilla::App -command;
 
@@ -86,9 +80,7 @@ sub opt_spec {
   [ 'omit-core=s', 'Omit dependencies that are shipped with the specified version of perl' ],
 }
 
-sub prereqs {
-  my ($self, $zilla) = @_;
-
+sub prereqs ($self, $zilla) {
   $_->before_build for @{ $zilla->plugins_with(-BeforeBuild) };
   $_->gather_files for @{ $zilla->plugins_with(-FileGatherer) };
   $_->set_file_encodings for @{ $zilla->plugins_with(-EncodingProvider) };
@@ -102,8 +94,7 @@ sub prereqs {
 my @phases = qw/configure build test runtime develop/;
 my @relationships = qw/requires recommends suggests/;
 
-sub filter_core {
-  my ($prereqs, $core_version) = @_;
+sub filter_core ($prereqs, $core_version) {
   $core_version = sprintf '%7.6f', $core_version if $core_version >= 5.010;
   $prereqs = $prereqs->clone if $prereqs->is_finalized;
   require Module::CoreList;
@@ -119,9 +110,7 @@ sub filter_core {
   return $prereqs;
 }
 
-sub extract_dependencies {
-  my ($self, $zilla, $phases, $opt) = @_;
-
+sub extract_dependencies ($self, $zilla, $phases, $opt) {
   my $prereqs = $self->prereqs($zilla);
   $prereqs = filter_core($prereqs, $opt->omit_core) if $opt->omit_core;
 
@@ -155,9 +144,7 @@ sub extract_dependencies {
   return map { $_ => $versions->{$_} } @required;
 }
 
-sub execute {
-  my ($self, $opt, $arg) = @_;
-
+sub execute ($self, $opt, $arg) {
   $self->app->chrome->logger->mute;
 
   my @phases = qw(build test configure runtime);
@@ -200,7 +187,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -213,11 +200,12 @@ command, which prints your distribution's prerequisites. You could pipe that
 list to a CPAN client like L<cpan> to install all of the dependencies in one
 quick go.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -274,11 +262,11 @@ API.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
