@@ -1,13 +1,7 @@
-package Dist::Zilla::App::Command::new 6.018; # TRIAL
+package Dist::Zilla::App::Command::new 6.026; # TRIAL
 # ABSTRACT: mint a new dist
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Dist::Zilla::App -command;
 
@@ -59,9 +53,7 @@ sub opt_spec {
   # [ 'module|m=s@', 'module(s) to create; may be given many times'         ],
 }
 
-sub validate_args {
-  my ($self, $opt, $args) = @_;
-
+sub validate_args ($self, $opt, $args) {
   require MooseX::Types::Perl;
 
   $self->usage_error('dzil new takes exactly one argument') if @$args != 1;
@@ -77,9 +69,7 @@ sub validate_args {
   $args->[0] = $name;
 }
 
-sub execute {
-  my ($self, $opt, $arg) = @_;
-
+sub execute ($self, $opt, $arg) {
   my $dist = $arg->[0];
 
   require Dist::Zilla::Dist::Minter;
@@ -115,7 +105,7 @@ Dist::Zilla::App::Command::new - mint a new dist
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -149,11 +139,12 @@ in the F<~/.dzil/config.ini> file, for example:
   provider = FooCorp
   profile = work
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -162,11 +153,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
