@@ -1,15 +1,9 @@
-package Dist::Zilla::Chrome::Term 6.018; # TRIAL
+package Dist::Zilla::Chrome::Term 6.026; # TRIAL
 # ABSTRACT: chrome used for terminal-based interaction
 
 use Moose;
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Digest::MD5 qw(md5);
 use Dist::Zilla::Types qw(OneZero);
@@ -25,9 +19,7 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
-sub _str_color {
-  my ($str) = @_;
-
+sub _str_color ($str) {
   state %color_for;
 
   # I know, I know, this is ludicrous, but guess what?  It's my Sunday and I
@@ -117,8 +109,7 @@ has term_enc => (
   },
 );
 
-sub prompt_str {
-  my ($self, $prompt, $arg) = @_;
+sub prompt_str ($self, $prompt, $arg) {
   $arg ||= {};
   my $default = $arg->{default};
   my $check   = $arg->{check};
@@ -158,8 +149,7 @@ sub prompt_str {
   return $input;
 }
 
-sub prompt_yn {
-  my ($self, $prompt, $arg) = @_;
+sub prompt_yn ($self, $prompt, $arg) {
   $arg ||= {};
   my $default = $arg->{default};
 
@@ -186,8 +176,7 @@ sub _isa_tty {
   return $isa_tty;
 }
 
-sub prompt_any_key {
-  my ($self, $prompt) = @_;
+sub prompt_any_key ($self, $prompt) {
   $prompt ||= 'press any key to continue';
 
   my $isa_tty = $self->_isa_tty;
@@ -221,18 +210,19 @@ Dist::Zilla::Chrome::Term - chrome used for terminal-based interaction
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 OVERVIEW
 
 This class provides a L<Dist::Zilla::Chrome> implementation for use in a
 terminal environment.  It's the default chrome used by L<Dist::Zilla::App>.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -241,11 +231,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
