@@ -1,16 +1,10 @@
-package Dist::Zilla::Dist::Builder 6.018; # TRIAL
+package Dist::Zilla::Dist::Builder 6.026; # TRIAL
 # ABSTRACT: dist zilla subclass for building dists
 
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use MooseX::Types::Moose qw(HashRef);
 use Dist::Zilla::Types qw(Path);
@@ -40,8 +34,7 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
-sub from_config {
-  my ($class, $arg) = @_;
+sub from_config ($class, $arg) {
   $arg ||= {};
 
   my $root = path($arg->{dist_root} || '.');
@@ -60,8 +53,7 @@ sub from_config {
   return $self;
 }
 
-sub _setup_default_plugins {
-  my ($self) = @_;
+sub _setup_default_plugins ($self) {
   unless ($self->plugin_named(':InstallModules')) {
     require Dist::Zilla::Plugin::FinderCode;
     my $plugin = Dist::Zilla::Plugin::FinderCode->new({
@@ -233,9 +225,7 @@ has _share_dir_map => (
   builder   => '_build_share_dir_map',
 );
 
-sub _build_share_dir_map {
-  my ($self) = @_;
-
+sub _build_share_dir_map ($self) {
   my $share_dir_map = {};
 
   for my $plugin (@{ $self->plugins_with(-ShareDir) }) {
@@ -260,8 +250,7 @@ sub _build_share_dir_map {
 }
 
 
-sub _load_config {
-  my ($class, $arg) = @_;
+sub _load_config ($class, $arg) {
   $arg ||= {};
 
   my $config_class =
@@ -341,9 +330,7 @@ END_DIE
 
 sub build { $_[0]->build_in }
 
-sub build_in {
-  my ($self, $root) = @_;
-
+sub build_in ($self, $root) {
   $self->log_fatal("tried to build with a minter")
     if $self->isa('Dist::Zilla::Dist::Minter');
 
@@ -419,9 +406,7 @@ sub ensure_built {
   $_[0]->ensure_built_in;
 }
 
-sub ensure_built_in {
-  my ($self, $root) = @_;
-
+sub ensure_built_in ($self, $root = undef) {
   # $root ||= $self->name . q{-} . $self->version;
   return $self->built_in if $self->built_in and
     (!$root or ($self->built_in eq $root));
@@ -440,8 +425,7 @@ sub ensure_built_in {
 #pod
 #pod =cut
 
-sub dist_basename {
-  my ($self) = @_;
+sub dist_basename ($self) {
   return join(q{},
     $self->name,
     '-',
@@ -449,6 +433,22 @@ sub dist_basename {
   );
 }
 
+#pod =method archive_basename
+#pod
+#pod   my $basename = $zilla->archive_basename;
+#pod
+#pod This method will return the filename, without the format extension
+#pod (e.g. C<Dist-Name-1.01> or C<Dist-Name-1.01-TRIAL>).
+#pod
+#pod =cut
+
+sub archive_basename ($self) {
+  return join q{},
+    $self->dist_basename,
+    ( $self->is_trial && $self->version !~ /_/ ? '-TRIAL' : '' ),
+  ;
+}
+
 #pod =method archive_filename
 #pod
 #pod   my $tarball = $zilla->archive_filename;
@@ -460,13 +460,8 @@ sub dist_basename {
 #pod
 #pod =cut
 
-sub archive_filename {
-  my ($self) = @_;
-  return join(q{},
-    $self->dist_basename,
-    ( $self->is_trial && $self->version !~ /_/ ? '-TRIAL' : '' ),
-    '.tar.gz'
-  );
+sub archive_filename ($self) {
+  return join q{}, $self->archive_basename, '.tar.gz';
 }
 
 #pod =method build_archive
@@ -478,22 +473,24 @@ sub archive_filename {
 #pod
 #pod =cut
 
-sub build_archive {
-  my ($self) = @_;
-
+sub build_archive ($self) {
   my $built_in = $self->ensure_built;
 
-  my $basename = $self->dist_basename;
-  my $basedir = path($basename);
+  my $basedir = path($self->dist_basename);
 
-  $_->before_archive for @{ $self->plugins_with(-BeforeArchive) };
+  $_->before_archive for $self->plugins_with(-BeforeArchive)->@*;
+
+  for my $builder ($self->plugins_with(-ArchiveBuilder)->@*) {
+    my $file = $builder->build_archive($self->archive_basename, $built_in, $basedir);
+    return $file if defined $file;
+  }
 
   my $method = eval { +require Archive::Tar::Wrapper;
                       Archive::Tar::Wrapper->VERSION('0.15'); 1 }
              ? '_build_archive_with_wrapper'
              : '_build_archive';
 
-  my $archive = $self->$method($built_in, $basename, $basedir);
+  my $archive = $self->$method($built_in, $basedir);
 
   my $file = path($self->archive_filename);
 
@@ -503,9 +500,7 @@ sub build_archive {
   return $file;
 }
 
-sub _build_archive {
-  my ($self, $built_in, $basename, $basedir) = @_;
-
+sub _build_archive ($self, $built_in, $basedir) {
   $self->log("building archive with Archive::Tar; install Archive::Tar::Wrapper 0.15 or newer for improved speed");
 
   require Archive::Tar;
@@ -535,9 +530,7 @@ sub _build_archive {
   return $archive;
 }
 
-sub _build_archive_with_wrapper {
-  my ($self, $built_in, $basename, $basedir) = @_;
-
+sub _build_archive_with_wrapper ($self, $built_in, $basedir) {
   $self->log("building archive with Archive::Tar::Wrapper");
 
   my $archive = Archive::Tar::Wrapper->new;
@@ -558,9 +551,7 @@ sub _build_archive_with_wrapper {
   return $archive;
 }
 
-sub _prep_build_root {
-  my ($self, $build_root) = @_;
-
+sub _prep_build_root ($self, $build_root) {
   $build_root = path($build_root || $self->dist_basename);
 
   $build_root->mkpath unless -d $build_root;
@@ -625,9 +616,7 @@ sub release {
 #pod
 #pod =cut
 
-sub clean {
-  my ($self, $dry_run) = @_;
-
+sub clean ($self, $dry_run) {
   require File::Path;
   for my $x (grep { -e } '.build', glob($self->name . '-*')) {
     if ($dry_run) {
@@ -702,8 +691,7 @@ sub ensure_built_in_tmpdir {
 #pod
 #pod =cut
 
-sub install {
-  my ($self, $arg) = @_;
+sub install ($self, $arg) {
   $arg ||= {};
 
   my ($target, $latest) = $self->ensure_built_in_tmpdir;
@@ -751,9 +739,7 @@ sub install {
 #pod
 #pod =cut
 
-sub test {
-  my ($self, $arg) = @_;
-
+sub test ($self, $arg = {}) {
   Carp::croak("you can't test without any TestRunner plugins")
     unless my @testers = @{ $self->plugins_with(-TestRunner) };
 
@@ -783,9 +769,7 @@ sub test {
 #pod
 #pod =cut
 
-sub run_tests_in {
-  my ($self, $target, $arg) = @_;
-
+sub run_tests_in ($self, $target, $arg = {}) {
   Carp::croak("you can't test without any TestRunner plugins")
     unless my @testers = @{ $self->plugins_with(-TestRunner) };
 
@@ -807,9 +791,7 @@ sub run_tests_in {
 #pod
 #pod =cut
 
-sub run_in_build {
-  my ($self, $cmd, $arg) = @_;
-
+sub run_in_build ($self, $cmd, $arg) {
   $self->log_fatal("you can't build without any BuildRunner plugins")
     unless ($arg and exists $arg->{build} and ! $arg->{build})
         or @{ $self->plugins_with(-BuildRunner) };
@@ -857,9 +839,7 @@ sub run_in_build {
 # C<-BuildRunner> plugins to generate it.  Useful for commands that operate on
 # F<blib>, such as C<test> or C<run>.
 
-sub _ensure_blib {
-  my ($self) = @_;
-
+sub _ensure_blib ($self) {
   unless ( -d 'blib' ) {
     my @builders = @{ $self->plugins_with( -BuildRunner ) };
     $self->log_fatal("no BuildRunner plugins specified") unless @builders;
@@ -883,13 +863,14 @@ Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -954,6 +935,13 @@ This method will return the dist's basename (e.g. C<Dist-Name-1.01>.
 The basename is used as the top-level directory in the tarball.  It
 does not include C<-TRIAL>, even if building a trial dist.
 
+=head2 archive_basename
+
+  my $basename = $zilla->archive_basename;
+
+This method will return the filename, without the format extension
+(e.g. C<Dist-Name-1.01> or C<Dist-Name-1.01-TRIAL>).
+
 =head2 archive_filename
 
   my $tarball = $zilla->archive_filename;
@@ -1044,11 +1032,11 @@ non-zero, the directory will be left in place.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
