@@ -1,16 +1,10 @@
-package Dist::Zilla::Dist::Minter 6.018; # TRIAL
+package Dist::Zilla::Dist::Minter 6.026; # TRIAL
 # ABSTRACT: distribution builder; installer not included!
 
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use File::pushd ();
 use Dist::Zilla::Path;
@@ -18,9 +12,7 @@ use Module::Runtime 'require_module';
 
 use namespace::autoclean;
 
-sub _setup_default_plugins {
-  my ($self) = @_;
-
+sub _setup_default_plugins ($self) {
   unless ($self->plugin_named(':DefaultModuleMaker')) {
     require Dist::Zilla::Plugin::TemplateModule;
     my $plugin = Dist::Zilla::Plugin::TemplateModule->new({
@@ -32,8 +24,7 @@ sub _setup_default_plugins {
   }
 }
 
-sub _new_from_profile {
-  my ($class, $profile_data, $arg) = @_;
+sub _new_from_profile ($class, $profile_data, $arg) {
   $arg ||= {};
 
   my $config_class =
@@ -89,9 +80,7 @@ sub _new_from_profile {
   return $self;
 }
 
-sub _mint_target_dir {
-  my ($self) = @_;
-
+sub _mint_target_dir ($self) {
   my $name = $self->name;
   my $dir  = path($name);
   $self->log_fatal("./$name already exists") if -e $dir;
@@ -99,9 +88,7 @@ sub _mint_target_dir {
   return $dir = $dir->absolute;
 }
 
-sub mint_dist {
-  my ($self, $arg) = @_;
-
+sub mint_dist ($self, $arg = {}) {
   my $name = $self->name;
   my $dir  = $self->_mint_target_dir;
 
@@ -160,13 +147,14 @@ Dist::Zilla::Dist::Minter - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -175,11 +163,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
