@@ -1,16 +1,10 @@
-package Dist::Zilla::MVP::Assembler::Zilla 6.018; # TRIAL
+package Dist::Zilla::MVP::Assembler::Zilla 6.026; # TRIAL
 # ABSTRACT: Dist::Zilla::MVP::Assembler for the Dist::Zilla object
 
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -31,9 +25,7 @@ use namespace::autoclean;
 use MooseX::Types::Perl qw(PackageName);
 use Dist::Zilla::MVP::RootSection;
 
-sub BUILD {
-  my ($self) = @_;
-
+sub BUILD ($self, @) {
   my $root = Dist::Zilla::MVP::RootSection->new;
   $self->sequence->add_section($root);
 }
@@ -52,8 +44,7 @@ has zilla_class => (
 #pod
 #pod =cut
 
-sub zilla {
-  my ($self) = @_;
+sub zilla ($self) {
   $self->sequence->section_named('_')->zilla;
 }
 
@@ -66,8 +57,7 @@ sub zilla {
 #pod
 #pod =cut
 
-sub register_stash {
-  my ($self, $name, $object) = @_;
+sub register_stash ($self, $name, $object) {
   $self->log_fatal("tried to register $name stash entry twice")
     if $self->zilla->_local_stashes->{ $name };
 
@@ -90,7 +80,7 @@ Dist::Zilla::MVP::Assembler::Zilla - Dist::Zilla::MVP::Assembler for the Dist::Z
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 OVERVIEW
 
@@ -104,11 +94,12 @@ future when minting and building use different subclasses of Dist::Zilla.)
 Upon construction, the assembler will create a L<Dist::Zilla::MVP::RootSection>
 as the initial section.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -132,11 +123,11 @@ is already taken, in which case an exception is raised.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
