@@ -1,13 +1,7 @@
-package Dist::Zilla::Path 6.018; # TRIAL
+package Dist::Zilla::Path 6.026; # TRIAL
 # ABSTRACT: a helper to get Path::Tiny objects
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use parent 'Path::Tiny';
 
@@ -20,9 +14,7 @@ use Sub::Exporter -setup => {
 
 use namespace::autoclean -except => 'import';
 
-sub path {
-  my ($thing, @rest) = @_;
-
+sub path ($thing, @rest) {
   if (@rest == 0 && blessed $thing) {
     return $thing if $thing->isa(__PACKAGE__);
 
@@ -35,11 +27,11 @@ sub path {
 
 my %warned;
 
-sub file {
-  my ($self, @file) = @_;
-
+sub file ($self, @file) {
   my ($package, $pmfile, $line) = caller;
-  unless ($warned{ $pmfile, $line }++) {
+
+  my $key = join qq{\0}, $pmfile, $line;
+  unless ($warned{ $key }++) {
     Carp::carp("->file called on a Dist::Zilla::Path object; this will cease to work in Dist::Zilla v7; downstream code should be updated to use Path::Tiny API, not Path::Class");
   }
 
@@ -47,8 +39,7 @@ sub file {
   Path::Class::dir($self)->file(@file);
 }
 
-sub subdir {
-  my ($self, @subdir) = @_;
+sub subdir ($self, @subdir) {
   Carp::carp("->subdir called on a Dist::Zilla::Path object; this will cease to work in Dist::Zilla v7; downstream code should be updated to use Path::Tiny API, not Path::Class");
   require Path::Class;
   Path::Class::dir($self)->subdir(@subdir);
@@ -68,13 +59,14 @@ Dist::Zilla::Path - a helper to get Path::Tiny objects
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -83,11 +75,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
