@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::AutoPrereqs 6.018; # TRIAL
+package Dist::Zilla::Plugin::AutoPrereqs 6.026; # TRIAL
 # ABSTRACT: automatically extract prereqs from your modules
 
 use Moose;
@@ -8,13 +8,7 @@ with(
   'Dist::Zilla::Role::PPI',
 );
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Moose::Util::TypeConstraints 'enum';
 use namespace::autoclean;
@@ -143,8 +137,7 @@ has type => (
   default => 'requires',
 );
 
-sub scan_file_reqs {
-  my ($self, $file) = @_;
+sub scan_file_reqs ($self, $file) {
   return $self->_scanner->scan_ppi_document($self->ppi_document_for_file($file))
 }
 
@@ -174,7 +167,7 @@ Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -203,11 +196,12 @@ scanned:
     encoding = bytes
     match    = ^t/data/
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -272,11 +266,11 @@ This plugin was originally contributed by Jerome Quelin.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
