@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::AutoVersion 6.018; # TRIAL
+package Dist::Zilla::Plugin::AutoVersion 6.026; # TRIAL
 # ABSTRACT: take care of numbering versions so you don't have to
 
 use Moose;
@@ -7,13 +7,7 @@ with(
   'Dist::Zilla::Role::TextTemplate',
 );
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -72,9 +66,7 @@ has format => (
             . q<{{$ENV{DEV} ? (sprintf '_%03u', $ENV{DEV}) : ''}}>
 );
 
-sub provide_version {
-  my ($self) = @_;
-
+sub provide_version ($self) {
   if (exists $ENV{V}) {
     $self->log_debug([ 'providing version %s', $ENV{V} ]);
     return $ENV{V};
@@ -135,18 +127,19 @@ Dist::Zilla::Plugin::AutoVersion - take care of numbering versions so you don't
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
 This plugin automatically produces a version string, generally based on the
 current time.  By default, it will be in the format: 1.yyDDDn
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -189,11 +182,11 @@ L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
