@@ -1,16 +1,10 @@
-package Dist::Zilla::Plugin::DistINI 6.018; # TRIAL
+package Dist::Zilla::Plugin::DistINI 6.026; # TRIAL
 # ABSTRACT: a plugin to add a dist.ini to newly-minted dists
 
 use Moose;
 with qw(Dist::Zilla::Role::FileGatherer);
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Dist::Zilla::File::FromCode;
 
@@ -67,9 +61,7 @@ has append_file => (
   default => sub { [] },
 );
 
-sub gather_files {
-  my ($self, $arg) = @_;
-
+sub gather_files ($self, $arg = {}) {
   my $zilla = $self->zilla;
 
   my $postlude = '';
@@ -124,7 +116,7 @@ Dist::Zilla::Plugin::DistINI - a plugin to add a dist.ini to newly-minted dists
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -136,11 +128,12 @@ minting facilities improve.  For example, it will not specify any plugins.
 
 In the meantime, you may be happier with a F<dist.ini> template.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -179,11 +172,11 @@ like this:
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
