@@ -1,16 +1,10 @@
-package Dist::Zilla::Plugin::Encoding 6.018; # TRIAL
+package Dist::Zilla::Plugin::Encoding 6.026; # TRIAL
 # ABSTRACT: set the encoding of arbitrary files
 
 use Moose;
 with 'Dist::Zilla::Role::EncodingProvider';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -86,9 +80,7 @@ has ignore => (
   default => sub { [] },
 );
 
-sub set_file_encodings {
-  my ($self) = @_;
-
+sub set_file_encodings ($self) {
   # never match (at least the filename characters)
   my $matches_regex = qr/\000/;
 
@@ -131,7 +123,7 @@ Dist::Zilla::Plugin::Encoding - set the encoding of arbitrary files
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -148,11 +140,12 @@ In your F<dist.ini>:
   filename = t/esperanto.t  ; this file is Esperanto
   match     = ^t/urkish/    ; these are all Turkish
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -183,11 +176,11 @@ that would otherwise be selected by C<matches>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
