@@ -1,16 +1,10 @@
-package Dist::Zilla::Plugin::ExtraTests 6.018; # TRIAL
+package Dist::Zilla::Plugin::ExtraTests 6.026; # TRIAL
 # ABSTRACT: rewrite ./xt tests to ./t tests with skips
 
 use Moose;
 with 'Dist::Zilla::Role::FileMunger';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -28,9 +22,7 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
-sub munge_file {
-  my ($self, $file) = @_;
-
+sub munge_file ($self, $file) {
   return unless $file->name =~ m{\Axt/(smoke|author|release)/.+\.t\z};
   my $method = "_rewrite_$1\_test";
 
@@ -39,24 +31,19 @@ sub munge_file {
   $self->$method($file);
 }
 
-sub _rewrite_smoke_test {
-  my ($self, $file) = @_;
+sub _rewrite_smoke_test ($self, $file) {
   $self->_rewrite($file, 'AUTOMATED_TESTING', '"smoke bot" testing');
 }
 
-sub _rewrite_author_test {
-  my ($self, $file) = @_;
+sub _rewrite_author_test ($self, $file) {
   $self->_rewrite($file, 'AUTHOR_TESTING', 'testing by the author');
 }
 
-sub _rewrite_release_test {
-  my ($self, $file) = @_;
+sub _rewrite_release_test ($self, $file) {
   $self->_rewrite($file, 'RELEASE_TESTING', 'release candidate testing');
 }
 
-sub _rewrite {
-  my ($self, $file, $env, $msg) = @_;
-
+sub _rewrite ($self, $file, $env, $msg) {
   my $name = $file->name =~ s{^xt/([^/]+)/}{t/$1-}r;
 
   $file->name($name);
@@ -90,7 +77,7 @@ Dist::Zilla::Plugin::ExtraTests - rewrite ./xt tests to ./t tests with skips
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -104,11 +91,12 @@ The tests are renamed and moved to F<./t>, and they are rewritten to include
 some simple Perl code to skip all included tests if the correct env vars are
 not set.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -117,11 +105,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
