@@ -1,17 +1,11 @@
-package Dist::Zilla::Plugin::GatherDir::Template 6.018; # TRIAL
+package Dist::Zilla::Plugin::GatherDir::Template 6.026; # TRIAL
 # ABSTRACT: gather all the files in a directory and use them as templates
 
 use Moose;
 extends 'Dist::Zilla::Plugin::GatherDir';
 with 'Dist::Zilla::Role::TextTemplate';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -72,9 +66,7 @@ around BUILDARGS => sub {
   return \%retargs;
 };
 
-sub _file_from_filename {
-  my ($self, $filename) = @_;
-
+sub _file_from_filename ($self, $filename) {
   my $template = path($filename)->slurp_utf8;
 
   my @stat = stat $filename or $self->log_fatal("$filename does not exist!");
@@ -126,7 +118,7 @@ Dist::Zilla::Plugin::GatherDir::Template - gather all the files in a directory a
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -141,11 +133,12 @@ object, respectively.
 It is meant to be used when minting dists with C<dzil new>, but could be used
 in building existing dists, too.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -170,11 +163,11 @@ same variables that the file itself receives, i.e. C<$dist> and C<$plugin>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
