@@ -1,16 +1,10 @@
-package Dist::Zilla::Plugin::ManifestSkip 6.018; # TRIAL
+package Dist::Zilla::Plugin::ManifestSkip 6.026; # TRIAL
 # ABSTRACT: decline to build files that appear in a MANIFEST.SKIP-like file
 
 use Moose;
 with 'Dist::Zilla::Role::FilePruner';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -41,8 +35,7 @@ use namespace::autoclean;
 
 has skipfile => (is => 'ro', required => 1, default => 'MANIFEST.SKIP');
 
-sub prune_files {
-  my ($self) = @_;
+sub prune_files ($self) {
   my $files = $self->zilla->files;
 
   my $skipfile_name = $self->skipfile;
@@ -98,7 +91,7 @@ Dist::Zilla::Plugin::ManifestSkip - decline to build files that appear in a MANI
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -109,11 +102,12 @@ skipped.
 This plugin is included in the L<@Basic|Dist::Zilla::PluginBundle::Basic>
 bundle.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -138,11 +132,11 @@ Other modules: L<ExtUtils::Manifest>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
