@@ -1,16 +1,10 @@
-package Dist::Zilla::Plugin::MetaConfig 6.018; # TRIAL
+package Dist::Zilla::Plugin::MetaConfig 6.026; # TRIAL
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -28,9 +22,7 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
-sub metadata {
-  my ($self) = @_;
-
+sub metadata ($self) {
   my $dump = { };
 
   my @plugins;
@@ -82,7 +74,7 @@ Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distm
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -96,11 +88,12 @@ more data to this dump.
 More information may be added to the top-level of this metadata as time goes
 on.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -113,11 +106,11 @@ Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
