@@ -1,16 +1,10 @@
-package Dist::Zilla::Plugin::MetaResources 6.018; # TRIAL
+package Dist::Zilla::Plugin::MetaResources 6.026; # TRIAL
 # ABSTRACT: provide arbitrary "resources" for distribution metadata
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -72,9 +66,7 @@ around BUILDARGS => sub {
   };
 };
 
-sub metadata {
-  my ($self) = @_;
-
+sub metadata ($self) {
   return { resources => $self->resources };
 }
 
@@ -101,7 +93,7 @@ Dist::Zilla::Plugin::MetaResources - provide arbitrary "resources" for distribut
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -115,11 +107,12 @@ This plugin adds resources entries to the distribution's metadata.
   repository.web    = http://github.com/dude/project
   repository.type   = git
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -134,11 +127,11 @@ Dist::Zilla plugins on the CPAN: L<GithubMeta|Dist::Zilla::Plugin::GithubMeta>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
