@@ -1,15 +1,9 @@
-package Dist::Zilla::Plugin::ModuleShareDirs 6.018; # TRIAL
+package Dist::Zilla::Plugin::ModuleShareDirs 6.026; # TRIAL
 # ABSTRACT: install a directory's contents as module-based "ShareDir" content
 
 use Moose;
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -29,8 +23,7 @@ has _module_map => (
   default => sub { {} },
 );
 
-sub find_files {
-  my ($self) = @_;
+sub find_files ($self) {
   my $modmap = $self->_module_map;
   my @files;
 
@@ -44,8 +37,7 @@ sub find_files {
   return \@files;
 }
 
-sub share_dir_map {
-  my ($self) = @_;
+sub share_dir_map ($self) {
   my $modmap = $self->_module_map;
 
   return unless keys %$modmap;
@@ -85,7 +77,7 @@ Dist::Zilla::Plugin::ModuleShareDirs - install a directory's contents as module-
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -95,11 +87,12 @@ In your F<dist.ini>:
   Foo::Bar = shares/foo_bar
   Foo::Baz = shares/foo_baz
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -108,11 +101,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
