@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::NextRelease 6.018; # TRIAL
+package Dist::Zilla::Plugin::NextRelease 6.026; # TRIAL
 # ABSTRACT: update the next release number in your changelog
 
 use Moose;
@@ -8,13 +8,7 @@ with (
   'Dist::Zilla::Role::AfterRelease',
 );
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -92,9 +86,7 @@ has _user_stash_obj => (
   default  => sub { $_[0]->zilla->stash_named( $_[0]->user_stash ) },
 );
 
-sub _user_info {
-  my ($self, $field) = @_;
-
+sub _user_info ($self, $field) {
   my $stash = $self->_user_stash_obj;
 
   $self->log_fatal([
@@ -105,9 +97,7 @@ sub _user_info {
   return $value;
 }
 
-sub section_header {
-  my ($self) = @_;
-
+sub section_header ($self) {
   return _format_version($self->format, $self);
 }
 
@@ -117,9 +107,7 @@ has _original_changes_content => (
   init_arg => undef,
 );
 
-sub munge_files {
-  my ($self) = @_;
-
+sub munge_files ($self) {
   my ($file) = grep { $_->name eq $self->filename } @{ $self->zilla->files };
   $self->log_fatal([ 'failed to find %s in the distribution', $self->filename ]) if not $file;
 
@@ -140,8 +128,7 @@ sub munge_files {
 }
 
 # new release is part of distribution history, let's record that.
-sub after_release {
-  my ($self) = @_;
+sub after_release ($self, $arg = {}) {
   my $filename = $self->filename;
   my ($gathered_file) = grep { $_->name eq $filename } @{ $self->zilla->files };
   $self->log_fatal("failed to find $filename in the distribution") if not $gathered_file;
@@ -289,7 +276,7 @@ Dist::Zilla::Plugin::NextRelease - update the next release number in your change
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -403,11 +390,12 @@ A tab
 
 =back
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -428,11 +416,11 @@ L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
