@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::PkgDist 6.018; # TRIAL
+package Dist::Zilla::Plugin::PkgDist 6.026; # TRIAL
 # ABSTRACT: add a $DIST to your packages
 
 use Moose;
@@ -10,13 +10,7 @@ with(
   'Dist::Zilla::Role::PPI',
 );
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -38,15 +32,11 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
-sub munge_files {
-  my ($self) = @_;
-
+sub munge_files ($self) {
   $self->munge_file($_) for @{ $self->found_files };
 }
 
-sub munge_file {
-  my ($self, $file) = @_;
-
+sub munge_file ($self, $file) {
   # XXX: for test purposes, for now! evil! -- rjbs, 2010-03-17
   return                          if $file->name    =~ /^corpus\//;
 
@@ -56,9 +46,7 @@ sub munge_file {
   return;
 }
 
-sub munge_perl {
-  my ($self, $file) = @_;
-
+sub munge_perl ($self, $file) {
   my $dist_name = $self->zilla->name;
 
   my $document = $self->ppi_document_for_file($file);
@@ -127,7 +115,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -145,11 +133,12 @@ C<package> keyword and the package name, like:
 This sort of declaration is also ignored by the CPAN toolchain, and is
 typically used when doing monkey patching or other tricky things.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -158,11 +147,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
