@@ -1,17 +1,11 @@
-package Dist::Zilla::Plugin::PruneCruft 6.018; # TRIAL
+package Dist::Zilla::Plugin::PruneCruft 6.026; # TRIAL
 # ABSTRACT: prune stuff that you probably don't mean to include
 
 use Moose;
 use Moose::Util::TypeConstraints;
 with 'Dist::Zilla::Role::FilePruner';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -56,17 +50,14 @@ use namespace::autoclean;
   sub mvp_multivalue_args { qw(except) }
 }
 
-sub _dont_exclude_file {
-  my ($self, $file) = @_;
+sub _dont_exclude_file ($self, $file) {
   for my $exception (@{ $self->except }) {
     return 1 if $file->name =~ $exception;
   }
   return;
 }
 
-sub exclude_file {
-  my ($self, $file) = @_;
-
+sub exclude_file ($self, $file) {
   return 0 if $self->_dont_exclude_file($file);
   return 1 if index($file->name, $self->zilla->name . '-') == 0;
   return 1 if $file->name =~ /\A\./;
@@ -93,9 +84,7 @@ sub exclude_file {
   return;
 }
 
-sub prune_files {
-  my ($self) = @_;
-
+sub prune_files ($self) {
   # Copy list (break reference) so we can mutate.
   for my $file ((), @{ $self->zilla->files }) {
     next unless $self->exclude_file($file);
@@ -123,7 +112,7 @@ Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to in
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -145,11 +134,12 @@ can be specified multiple times):
 This plugin is included in the L<@Basic|Dist::Zilla::PluginBundle::Basic>
 bundle.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -165,11 +155,11 @@ L<ManifestSkip|Dist::Zilla::Plugin::ManifestSkip>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
