@@ -1,16 +1,10 @@
-package Dist::Zilla::Plugin::TestRelease 6.018; # TRIAL
+package Dist::Zilla::Plugin::TestRelease 6.026; # TRIAL
 # ABSTRACT: extract archive and run tests before releasing the dist
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -34,8 +28,7 @@ use namespace::autoclean;
 use File::pushd ();
 use Dist::Zilla::Path;
 
-sub before_release {
-  my ($self, $tgz) = @_;
+sub before_release ($self, $tgz) {
   $tgz = $tgz->absolute;
 
   my $build_root = $self->zilla->root->child('.build');
@@ -81,7 +74,7 @@ Dist::Zilla::Plugin::TestRelease - extract archive and run tests before releasin
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
@@ -94,11 +87,12 @@ the release process continues.
 This will set the RELEASE_TESTING and AUTHOR_TESTING env vars while running the
 test suite.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -111,11 +105,11 @@ This plugin was originally contributed by Christopher J. Madsen.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
