@@ -1,16 +1,10 @@
-package Dist::Zilla::PluginBundle::Filter 6.018; # TRIAL
+package Dist::Zilla::PluginBundle::Filter 6.026; # TRIAL
 # ABSTRACT: use another bundle, with some plugins removed
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -35,7 +29,7 @@ use Dist::Zilla::Util;
 #pod includes all the configuration for the bundle named in the C<-bundle> attribute,
 #pod but removes all the entries whose package is given in the C<-remove> attributes.
 #pod
-#pod A minimum required version of the bundle can be specified with the C<-version> 
+#pod A minimum required version of the bundle can be specified with the C<-version>
 #pod attribute.
 #pod
 #pod Options not prefixed with C<-> will be passed to the bundle to be filtered.
@@ -53,8 +47,7 @@ use Dist::Zilla::Util;
 
 sub mvp_multivalue_args { qw(remove -remove) }
 
-sub bundle_config {
-  my ($self, $section) = @_;
+sub bundle_config ($self, $section) {
   my $class = (ref $self) || $self;
 
   my $config = {};
@@ -113,7 +106,7 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -132,7 +125,7 @@ This plugin bundle actually wraps and modifies another plugin bundle.  It
 includes all the configuration for the bundle named in the C<-bundle> attribute,
 but removes all the entries whose package is given in the C<-remove> attributes.
 
-A minimum required version of the bundle can be specified with the C<-version> 
+A minimum required version of the bundle can be specified with the C<-version>
 attribute.
 
 Options not prefixed with C<-> will be passed to the bundle to be filtered.
@@ -140,11 +133,12 @@ Options not prefixed with C<-> will be passed to the bundle to be filtered.
 B<NOTE:> When you filter a bundle you B<SHOULD NOT> include it directly in
 your C<dist.ini> file. This plugin will take care of including it for you.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -159,11 +153,11 @@ Dist::Zilla roles: L<PluginBundle|Dist::Zilla::Role::PluginBundle>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
