@@ -1,16 +1,10 @@
-package Dist::Zilla::Role::Plugin 6.018; # TRIAL
+package Dist::Zilla::Role::Plugin 6.026; # TRIAL
 # ABSTRACT: something that gets plugged in to Dist::Zilla
 
 use Moose::Role;
 with 'Dist::Zilla::Role::ConfigDumper';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Params::Util qw(_HASHLIKE);
 use Moose::Util::TypeConstraints 'class_type';
@@ -71,9 +65,7 @@ has logger => (
 sub mvp_multivalue_args {};
 sub mvp_aliases         { return {} };
 
-sub plugin_from_config {
-  my ($class, $name, $arg, $section) = @_;
-
+sub plugin_from_config ($class, $name, $arg, $section) {
   my $self = $class->new({
     %$arg,
     plugin_name => $name,
@@ -81,9 +73,7 @@ sub plugin_from_config {
   });
 }
 
-sub register_component {
-  my ($class, $name, $arg, $section) = @_;
-
+sub register_component ($class, $name, $arg, $section) {
   my $self = $class->plugin_from_config($name, $arg, $section);
 
   my $version = $self->VERSION || 0;
@@ -109,18 +99,19 @@ Dist::Zilla::Role::Plugin - something that gets plugged in to Dist::Zilla
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
 The Plugin role should be applied to all plugin classes.  It provides a few key
 methods and attributes that all plugins will need.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -147,11 +138,11 @@ L<Dist::Zilla/log> method after including a bit of argument-munging.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
