@@ -1,17 +1,11 @@
-package Dist::Zilla::Role::PluginBundle::Easy 6.018; # TRIAL
+package Dist::Zilla::Role::PluginBundle::Easy 6.026; # TRIAL
 # ABSTRACT: something that bundles a bunch of plugins easily
 # This plugin was originally contributed by Christopher J. Madsen
 
 use Moose::Role;
 with 'Dist::Zilla::Role::PluginBundle';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Module::Runtime 'use_module';
 use namespace::autoclean;
@@ -101,14 +95,12 @@ has plugins => (
   default  => sub { [] },
 );
 
-sub bundle_config {
-  my ($class, $section) = @_;
-
+sub bundle_config ($class, $section) {
   my $self = $class->new($section);
 
   $self->configure;
 
-  return @{ $self->plugins };
+  return $self->plugins->@*;
 }
 
 #pod =method add_plugins
@@ -130,9 +122,7 @@ sub bundle_config {
 #pod
 #pod =cut
 
-sub add_plugins {
-  my ($self, @plugin_specs) = @_;
-
+sub add_plugins ($self, @plugin_specs) {
   my $prefix  = $self->name . '/';
   my $plugins = $self->plugins;
 
@@ -166,9 +156,7 @@ sub add_plugins {
 #pod
 #pod =cut
 
-sub add_bundle {
-  my ($self, $bundle, $payload) = @_;
-
+sub add_bundle ($self, $bundle, $payload) {
   my $package = _bundle_class($bundle);
   $payload ||= {};
 
@@ -179,7 +167,7 @@ sub add_bundle {
 
   $bundle = "\@$bundle" unless $bundle =~ /^@/;
 
-  push @{ $self->plugins },
+  push $self->plugins->@*,
     $package->bundle_config({
       name    => $self->name . '/' . $bundle,
       package => $package,
@@ -236,7 +224,7 @@ Dist::Zilla::Role::PluginBundle::Easy - something that bundles a bunch of plugin
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 SYNOPSIS
 
@@ -259,11 +247,12 @@ for you.  In exchange, you must supply a C<configure> method, which will store
 the bundle's configuration in the C<plugins> attribute by calling
 C<add_plugins> and/or C<add_bundle>.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -337,11 +326,11 @@ key does not exist in C<payload>, then it is omitted from the result.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
