@@ -1,15 +1,9 @@
-package Dist::Zilla::Role::TextTemplate 6.018; # TRIAL
+package Dist::Zilla::Role::TextTemplate 6.026; # TRIAL
 # ABSTRACT: something that renders a Text::Template template string
 
 use Moose::Role;
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use namespace::autoclean;
 
@@ -52,9 +46,7 @@ has delim => (
 #pod
 #pod =cut
 
-sub fill_in_string {
-  my ($self, $string, $stash, $arg) = @_;
-
+sub fill_in_string ($self, $string, $stash = {}, $arg = {}) {
   $self->log_fatal("Cannot use undef as a template string")
     unless defined $string;
 
@@ -91,18 +83,19 @@ Dist::Zilla::Role::TextTemplate - something that renders a Text::Template templa
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
 Plugins implementing TextTemplate may call their own C<L</fill_in_string>>
 method to render templates using L<Text::Template|Text::Template>.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -132,11 +125,11 @@ C<new> routine.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
