@@ -1,16 +1,10 @@
-package Dist::Zilla::Tester 6.018; # TRIAL
+package Dist::Zilla::Tester 6.026; # TRIAL
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
 
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use autodie;
 use Dist::Zilla::Chrome::Test;
@@ -31,9 +25,7 @@ use Sub::Exporter -setup => {
 
 use namespace::autoclean -except => 'import';
 
-sub from_config {
-  my ($self, @arg) = @_;
-
+sub from_config ($self, @arg) {
   # The only thing using a local time zone should be NextRelease.  Normally it
   # defaults to "local," but since some users won't have an automatically
   # determinable time zone, we'll switch to not-local times for testing.
@@ -118,7 +110,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Builder 6.018; # TRIAL
+  package Dist::Zilla::Tester::_Builder 6.026; # TRIAL
 
   use Moose;
   extends 'Dist::Zilla::Dist::Builder';
@@ -232,13 +224,13 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
   };
 
   around ['test', 'release'] => sub {
-    my ($orig, $self) = @_;
+    my ($orig, $self, @rest) = @_;
 
     # XXX: We *must eliminate* the need for this!  It's only here because right
     # now building a dist with (root <> cwd) doesn't work. -- rjbs, 2010-03-08
     my $wd = File::pushd::pushd($self->root);
 
-    return $self->$orig;
+    return $self->$orig(@rest);
   };
 
   no Moose;
@@ -263,7 +255,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Minter 6.018; # TRIAL
+  package Dist::Zilla::Tester::_Minter 6.026; # TRIAL
 
   use Moose;
   extends 'Dist::Zilla::Dist::Minter';
@@ -375,13 +367,14 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -390,11 +383,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
