@@ -1,13 +1,7 @@
-package Test::DZil 6.018; # TRIAL
+package Test::DZil 6.026; # TRIAL
 # ABSTRACT: tools for testing Dist::Zilla plugins
 
-# BEGIN BOILERPLATE
-use v5.20.0;
-use warnings;
-use utf8;
-no feature 'switch';
-use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
-# END BOILERPLATE
+use Dist::Zilla::Pragmas;
 
 use Params::Util qw(_HASH0);
 use JSON::MaybeXS;
@@ -68,9 +62,7 @@ sub Minter {
 #pod
 #pod =cut
 
-sub is_filelist {
-  my ($have, $want, $comment) = @_;
-
+sub is_filelist ($have, $want, $comment) {
   my @want = @$want;
   my @have = map { my $str = (blessed $_ and
                               $_->DOES('Dist::Zilla::Role::File'))
@@ -91,9 +83,7 @@ sub is_filelist {
 #pod
 #pod =cut
 
-sub is_yaml {
-  my ($yaml, $want, $comment) = @_;
-
+sub is_yaml ($yaml, $want, $comment) {
   my $have = YAML::Tiny->read_string($yaml)
     or die "Cannot decode YAML";
 
@@ -110,9 +100,7 @@ sub is_yaml {
 #pod
 #pod =cut
 
-sub is_json {
-  my ($json, $want, $comment) = @_;
-
+sub is_json ($json, $want, $comment) {
   my $have = JSON::MaybeXS->new(ascii => 1)->decode($json)
     or die "Cannot decode JSON";
 
@@ -120,10 +108,7 @@ sub is_json {
   Test::Deep::cmp_deeply($have, $want, $comment);
 }
 
-sub _build_ini_builder {
-  my ($starting_core) = @_;
-  $starting_core ||= {};
-
+sub _build_ini_builder ($starting_core = {}) {
   sub {
     my (@arg) = @_;
     my $new_core = _HASH0($arg[0]) ? shift(@arg) : {};
@@ -259,17 +244,18 @@ Test::DZil - tools for testing Dist::Zilla plugins
 
 =head1 VERSION
 
-version 6.018
+version 6.026
 
 =head1 DESCRIPTION
 
 Test::DZil provides routines for writing tests for Dist::Zilla plugins.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -369,11 +355,11 @@ The starter config may change slightly over time, but is something like this:
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
